summaryrefslogtreecommitdiff
path: root/org/omg/CORBA_2_3/portable/OutputStream.java
diff options
context:
space:
mode:
Diffstat (limited to 'org/omg/CORBA_2_3/portable/OutputStream.java')
-rw-r--r--org/omg/CORBA_2_3/portable/OutputStream.java12
1 files changed, 7 insertions, 5 deletions
diff --git a/org/omg/CORBA_2_3/portable/OutputStream.java b/org/omg/CORBA_2_3/portable/OutputStream.java
index 70f9a4913..f1369f782 100644
--- a/org/omg/CORBA_2_3/portable/OutputStream.java
+++ b/org/omg/CORBA_2_3/portable/OutputStream.java
@@ -1,5 +1,5 @@
/* OutputStream.java --
- Copyright (C) 2005 Free Software Foundation, Inc.
+ Copyright (C) 2005, 2006 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -41,6 +41,8 @@ package org.omg.CORBA_2_3.portable;
import gnu.CORBA.CDR.Vio;
import org.omg.CORBA.portable.BoxedValueHelper;
+import org.omg.CORBA.portable.CustomValue;
+import org.omg.CORBA.portable.StreamableValue;
import org.omg.CORBA.portable.ValueBase;
import java.io.Serializable;
@@ -92,7 +94,7 @@ public abstract class OutputStream
* Writes a value type into the output stream.
*
* The value type must implement either {@link CustomValue} (for user-defined
* writing method) or {@link StramableValue} (for standard writing using code,
* generated by IDL compiler).
*
* The written record will have a repository id, matching the class of the
@@ -109,7 +111,7 @@ public abstract class OutputStream
* Write value to the stream using the boxed value helper.
*
* The value type must implement either {@link CustomValue}
- * (for user-defined writing method) or {@link StramableValue}
+ * (for user-defined writing method) or {@link StreamableValue}
* (for standard writing using code, generated by IDL compiler).
*
* @param value a value to write.
@@ -129,7 +131,7 @@ public abstract class OutputStream
* writing two Id inheritance hierarchy.
*
* The value type must implement either {@link CustomValue}
- * (for user-defined writing method) or {@link StramableValue}
+ * (for user-defined writing method) or {@link StreamableValue}
* (for standard writing using code, generated by IDL compiler).
*
* @param value a value type object to write.
@@ -144,7 +146,7 @@ public abstract class OutputStream
* repository id.
*
* The value type must implement either {@link CustomValue} (for user-defined
* writing method) or {@link StramableValue} (for standard writing using code,
* generated by IDL compiler).
*
* @param repository_id a repository id of the value type.
@@ -92,7 +94,7 @@ public abstract class OutputStream
*
* The value type must implement either {@link CustomValue} (for user-defined
- * writing method) or {@link StramableValue} (for standard writing using code,
+ * writing method) or {@link StreamableValue} (for standard writing using code,
* generated by IDL compiler).
*
@@ -144,7 +146,7 @@ public abstract class OutputStream
*
* The value type must implement either {@link CustomValue} (for user-defined
- * writing method) or {@link StramableValue} (for standard writing using code,
+ * writing method) or {@link StreamableValue} (for standard writing using code,
* generated by IDL compiler).
*